@@ -30,7 +30,7 @@
  DAMAGE. 
  =========================================================================*/
 
-/* $Id: global-cscope.h,v 1.6 2015/06/22 06:42:38 shigio Exp $ */
+/* $Id: global-cscope.h,v 1.8 2018/01/12 00:18:02 shigio Exp $ */
 
 /*
  *	global type, data, and function definitions
@@ -176,6 +176,19 @@ typedef RETSIGTYPE (*sighandler_t)(int);
 # define	lstat(file,buf)	stat(file,buf)
 #endif
 
+#ifndef __attribute__
+/* This feature is available in gcc versions 2.5 and later.  */
+# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5) || __STRICT_ANSI__
+#  define __attribute__(x)
+# endif
+/* The __-protected variants of `format' and `printf' attributes
+   are accepted by gcc versions 2.6.4 (effectively 2.7) and later.  */
+# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 7)
+#  define __format__ format
+#  define __printf__ printf
+# endif
+#endif
+
 typedef	enum	{		/** boolean data type */
 	NO,
 	YES
@@ -270,6 +283,7 @@ char	*findallfcns(char *dummy);
 char	*finddef(char *pattern);
 char	*findfile(char *dummy);
 char	*findinclude(char *pattern);
+char	*findassign(char *pattern);
 char	*findsymbol(char *pattern);
 char	*findregexp(char *egreppat);
 char	*findstring(char *pattern);
@@ -316,8 +330,10 @@ void	progress(char *what, long current, long max);
 void	putfilename(char *srcfile);
 void	postmsg(char *msg);
 void	postmsg2(char *msg);
-void	posterr(char *msg,...);
-void	postfatal(const char *msg,...);
+void	posterr(char *msg,...)
+	__attribute__ ((__format__ (__printf__, 1, 2)));
+void	postfatal(const char *msg,...)
+	__attribute__ ((__format__ (__printf__, 1, 2)));
 void	putposting(char *term, int type);
 void	fetch_string_from_dbase(char *, size_t);
 void	resetcmd(void);
