@@ -35,19 +35,15 @@
 #include "varray.h"
 #include "strbuf.h"
 
-/** @name File buffer */
-/** @{ */
+/* File buffer */
 #define EXPAND 1024
 static STRBUF *ib;
 static char *filebuf;
 static int filesize;
-/** @} */
 
-/** @name File pointer */
-/** @{ */
+/* File pointer */
 static char *curp;
 static char *endp;
-/** @} */
 
 /** Offset table */
 static VARRAY *vb;
@@ -57,7 +53,7 @@ static void linetable_put(int, int);
  * linetable_open: load whole of file into memory.
  *
  *	@param[in]	path	path
- *	@return		0: normal <br>
+ *	@return		0: normal,
  *			-1: cannot open file.
  */
 int
@@ -90,11 +86,11 @@ linetable_open(const char *path)
 	return 0;
 }
 /**
- * linetable_read: @XREF{read,2} compatible routine for linetable.
+ * linetable_read: read(2) compatible routine for linetable.
  *
  *	@param[in,out]	buf	read buffer
  *	@param[in]	size	buffer size
- *	@return		==-1: end of file <br>
+ *	@return		==-1: end of file,
  *			!=-1: number of bytes actually read
  */
 int
@@ -115,7 +111,7 @@ linetable_read(char *buf, int size)
  * linetable_put: put a line into table.
  *
  *	@param[in]	offset	offset of the line
- *	@param[in]	lineno	line number of the line (\>= 1)
+ *	@param[in]	lineno	line number of the line (>= 1)
  */
 void
 linetable_put(int offset, int lineno)
@@ -130,9 +126,9 @@ linetable_put(int offset, int lineno)
 /**
  * linetable_get: get a line from table.
  *
- *	@param[in]	lineno	line number of the line (\>= 1)
- *	@param[out]	offset	offset of the line <br>
- *			if @CODE{offset == NULL}, nothing returned.
+ *	@param[in]	lineno	line number of the line (>= 1)
+ *	@param[out]	offset	offset of the line,
+ *			if offset == NULL, nothing returned.
  *	@return		line pointer
  */
 char *
@@ -160,7 +156,7 @@ linetable_close(void)
  * linetable_print: print a line.
  *
  *	@param[in]	op	output file pointer
- *	@param[in]	lineno	line number (\>= 1)
+ *	@param[in]	lineno	line number (>= 1)
  */
 void
 linetable_print(FILE *op, int lineno)
